# Please keep this package in sync with FC

%global major   5
%define libname %mklibname capstone %major
%define devname %mklibname capstone -d

Name:           capstone
Version:        5.0.6
Release:        %mkrel 1
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
License:        BSD-3-Clause AND BSD-4-Clause AND APSL-2.0 AND NCSA AND MIT
URL:            https://www.capstone-engine.org/
VCS:            https://github.com/capstone-engine/capstone/
#               https://github.com/capstone-engine/capstone/releases

%global         common_desc %{expand:
Capstone is a disassembly framework with the target of becoming the ultimate
disasm engine for binary analysis and reversing in the security community.}


%define _lto_cflags %{nil}

Group:          System/Libraries

%global         gituser         capstone-engine
%global         gitname         capstone
# 5.0.1 release
%global         gitdate         20230823
%global         commit          097c04d9413c59a58b00d4d1c8d5dc0ac158ffaa
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

#               https://github.com/capstone-engine/capstone/releases
Source0:        https://github.com/capstone-engine/capstone/releases/download/%{version}/%{name}-%{version}.tar.xz

# Manpage for cstool is missing in the package, add one generated by help2man
Source1:        cstool.1

# Ocaml binding is not using local path for the includes/links
Patch1:         capstone-5.0.1-ocaml.patch


# Build with python3 package by default
%bcond_without  python3

# Build with java binding
%bcond_without  java

# Build without ocaml binding - it is not ready to be distributed as ocaml shared library
%bcond_with  ocaml



%global srcname distribute

BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  git

%if %{with java}
BuildRequires:  jna
BuildRequires:  java-devel
%endif

%if %{with python3}
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  python3-pytest
%endif

%if %{with ocaml}
BuildRequires:  ocaml
BuildRequires:  ocaml-ocamlbuild
%endif

%description
%{common_desc}

%package        -n %libname
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
Group:          System/Libraries
Obsoletes:      %{_lib}capstone0 < 3.0.4-3

%description    -n %libname
Library for Capstone.
%{common_desc}

%package        -n %devname
Summary:        Development files for %{name}
Group:		Development/Other
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:	capstone-devel = %{version}-%{release}

%description    -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with python3}
%package	-n python3-capstone
#BuildArch:      noarch
Summary:	Python3 bindings for %{name}
Group:		Development/Python
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description	-n python3-capstone
%{common_desc}
The python3-%{name} package contains python3 bindings for %{name}.
%endif


%if %{with java}
%package        java
Summary:        Java bindings for %{name}
Group:          Development/Java
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch

%description    java
%{common_desc}
The %{name}-java package contains java bindings for %{name}.
%endif

%if %{with ocaml}
%package        -n ocaml-%{name}
Summary:        OCaml bindings for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    -n ocaml-%{name}
%{common_desc}
The ocaml-%{name} package contains OCaml bindings for %{name}.
%endif


%prep
%autosetup -n %{gitname}-%{version} -p1

%if %{with python3}
pushd bindings/python
%pyproject_buildrequires
popd
%endif


%build
V=1 CFLAGS="%{optflags}" \
PREFIX="%{_prefix}" LIBDIRARCH="%{_lib}" INCDIR="%{_includedir}" \
%make_build PYTHON3=%{__python3}

# Fix pkgconfig file
grep -v archive capstone.pc > capstone.pc.tmp
mv capstone.pc.tmp capstone.pc

# build python bindings
%if %{with python3}
pushd bindings/python
%pyproject_wheel
%endif
popd

%if %{with java}
# build java bindings needs some python runtime
pushd bindings/java
%make_build PYTHON2=%{__python3} CFLAGS="%{optflags}" # %{?_smp_mflags} parallel seems broken
popd
%endif

%if %{with ocaml}
pushd bindings/ocaml
# build ocaml bindings needs some python runtime
%if %{with python3}
%make_build PYTHON2=%{__python3} CFLAGS="%{optflags}" -j1 # %{?_smp_mflags} parallel seems broken
%else
%make_build PYTHON2=%{__python2} PYTHON3=%{__python2} CFLAGS="%{optflags}" -j1 # %{?_smp_mflags} parallel seems broken
%endif
popd
%endif

%install
DESTDIR=%{buildroot} PREFIX="%{_prefix}" LIBDIRARCH=%{_lib} \
INCDIR="%{_includedir}" make install

# cleanup static libraries
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name '*.a' -delete

# add the manpage
install -d -D %{buildroot}%{_mandir}/man1
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_mandir}/man1/

# install python bindings
%if %{with python3}
pushd bindings/python
%pyproject_install
%pyproject_save_files capstone
%endif
popd

%if %{with java}
# install java bindings
install -D -p -m 0644 bindings/java/%{name}.jar  %{buildroot}%{_javadir}/%{name}.jar
%endif

%if %{with ocaml}
# install ocaml binding
%endif

%check
# ln -s libcapstone.so.5 libcapstone.so
make check LD_LIBRARY_PATH="`pwd`"

%if %{with python3}
pushd bindings/python
#pytest -sv -k "not testcb and not test_cs_disasm_quick"
popd
%endif

%if %{with ocaml}
pushd bindings/ocaml
make check LD_LIBRARY_PATH="`pwd`"
popd
%endif

%files
%license LICENSE.TXT LICENSE_LLVM.TXT
%doc CREDITS.TXT ChangeLog README.md SPONSORS.TXT
%{_bindir}/cstool
%{_mandir}/man1/cstool.1*

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %devname
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*


%if %{with python3}
%files -n python3-capstone -f %{pyproject_files}
%exclude %{python3_sitelib}/capstone/include/
%exclude %{python3_sitelib}/capstone/lib/
%endif


%if %{with java}
%files java
%{_javadir}/
%endif


%if %{with ocaml}
%files -n ocaml-%{name}
%endif




%changelog
* Sat Apr 05 2025 daviddavid <daviddavid> 5.0.6-1.mga10
+ Revision: 2173588
- new version: 5.0.6

* Sat Mar 01 2025 papoteur <papoteur> 5.0.5-2.mga10
+ Revision: 2154467
- rebuild for python3.13

* Thu Jan 23 2025 daviddavid <daviddavid> 5.0.5-1.mga10
+ Revision: 2140718
- new version: 5.0.5

* Mon Dec 18 2023 papoteur <papoteur> 5.0.1-2.mga10
+ Revision: 2018943
- Mass Rebuild - Python 3.12

* Sat Dec 09 2023 tv <tv> 5.0.1-1.mga10
+ Revision: 2016109
- Update to 5.0.1
- Modernize spec file using pyproject/wheel build
- update the new github page

* Sat Jun 18 2022 wally <wally> 4.0.2-7.mga9
+ Revision: 1864770
- stop building capstone lib again with python binding

* Fri Apr 01 2022 umeabot <umeabot> 4.0.2-6.mga9
+ Revision: 1838707
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 wally <wally> 4.0.2-5.mga9
+ Revision: 1775219
- rebuild for python3.10

* Fri Dec 10 2021 wally <wally> 4.0.2-4.mga9
+ Revision: 1761356
- drop duplicate files between lib and py3 pkgs

* Fri Dec 10 2021 wally <wally> 4.0.2-3.mga9
+ Revision: 1761343
- properly filter out lib provides from python3 pkg

* Mon Mar 22 2021 daviddavid <daviddavid> 4.0.2-2.mga9
+ Revision: 1707731
- rebuild for python 3.9

* Mon May 11 2020 tv <tv> 4.0.2-1.mga8
+ Revision: 1582891
- 4.0.2

* Sun Feb 16 2020 umeabot <umeabot> 4.0.1-4.mga8
+ Revision: 1532197
- Mageia 8 Mass Rebuild

* Mon Sep 16 2019 tv <tv> 4.0.1-3.mga8
+ Revision: 1442077
- rebuild for python-3.8
- drop python2 subpkg
- rebuild for rpm-4.15

* Sat Jan 12 2019 tv <tv> 4.0.1-1.mga7
+ Revision: 1355753
- new release
- major is now 4

* Tue Jan 08 2019 shlomif <shlomif> 3.0.5-4.mga7
+ Revision: 1351561
- Rebuild for python3 3.7

* Tue Sep 11 2018 wally <wally> 3.0.5-3.mga7
+ Revision: 1258446
- don't provide libcapstone.so.3 with python pkgs

* Thu Aug 30 2018 daviddavid <daviddavid> 3.0.5-2.mga7
+ Revision: 1255695
- fix dependencies

* Tue Aug 28 2018 tv <tv> 3.0.5-1.mga7
+ Revision: 1255270
- 3.0.5

* Sat Feb 10 2018 daviddavid <daviddavid> 3.0.4-3.mga7
+ Revision: 1200017
- fix requires
- libmajor is 3
- use new python macros

* Mon Nov 27 2017 tv <tv> 3.0.4-2.mga7
+ Revision: 1179996
- add missing provides
- imported package capstone


* Mon Nov 27 2017 Thierry Vignaud <tv@mageia.org> 3.0.4-1.mga7
- import from FC

* Sun Aug 20 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.0.4-12
- Add Provides for the old name without %%_isa

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.0.4-11
- Python 2 binary package renamed to python2-capstone
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.4-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.0.4-7
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.4-6
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 27 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.4-4
- Really add dist tag this time

* Sun Oct 25 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.4-3
- Fix issues found during package review: dist tag, git sources

* Thu Jul 16 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.4-2
- Fix EPEL6 build problems

* Wed Jul 15 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.4-1
- new version 3.0.4. Includes security fixes.

* Tue May 12 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.3-2
- Addressed issues found during package review.

* Fri May 08 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.3-1
-  Update to version 3.0.3

* Fri May 08 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.2-3
- Added python3 and hardened build support. Update java building.
- Various cleanups.

* Wed May 06 2015 Stefan Cornelius <scorneli@redhat.com> - 3.0.2-2
- Update to 3.0.2. Fix 64bit issues. add %%check.

* Sat Sep 27 2014 Adel Gadllah <adel.gadllah@gmail.com> - 2.1.2-2
- Addressed issues found during package review.

* Mon May 19 2014 Adel Gadllah <adel.gadllah@gmail.com> - 2.1.2-1
- Initial package
